@@ -385,6 +385,9 @@ class EquilibriumConditions:
         self.id_cond+=1
         return cond_out
 
+    def get_eq_conditions(self):
+        return self.eq_conditions
+
     def get_elements(self):
         return self.elements_fix_chempots+self.elements_fix_Natoms
 
