@@ -584,6 +584,9 @@ def plot_defect_densities(plot_params_in={}):
                 num_max=n1
                 param_max=k1
         plot_params_in["dens_xaxis_parameter"]=param_max
+    bool_fixNatoms_linked=False
+    if plot_params_in["dens_xaxis_parameter"].find("fix_Natoms_linked")==0:
+        bool_fixNatoms_linked=True
     if plot_params_in["dens_xlabel"]=="NONE":
         if plot_params_in["dens_xaxis_parameter"]=="temperature":
             plot_params_in["dens_xlabel"]=r"Temperature [K]"
@@ -626,6 +629,8 @@ def plot_defect_densities(plot_params_in={}):
     eq_conditions=[]
     eq_conditions_labels=[]
     for k1,v1 in parameters_list_exclmain.items():
+        if bool_fixNatoms_linked and k1.find("fix_Natoms_")==0:
+            continue
         if len(eq_conditions)==0:
             eq_conditions=v1
         else:
@@ -688,19 +693,28 @@ def plot_defect_densities(plot_params_in={}):
                 if "+" in label_def4:
                     label_def4="["+label_def4+"]"
                 label_charge=label_def1[label_def1.find("{")+1:label_def1.find("}")]
-                if int(label_charge)>0:
+                label_charge_int=int(label_charge)
+                if label_charge_int==-1:
+                    label_charge="-"
+                elif label_charge_int==1:
+                    label_charge="+"
+                elif label_charge_int>1:
                     label_charge="+"+label_charge
+                elif label_charge_int<-1:
+                    label_charge="-"+label_charge[1:]
                 label_id=label_def1[label_def1.find("(")+1:label_def1.find(")")]
                 label_legend="\mathrm{"+label_def4+"^{"+label_charge+"}}"
                 if int(label_id)>0:
                     label_legend=label_legend+"("+label_id+")"
                 label_legend="$"+label_legend+"$"
-            datalist2[k1]["label_lagend_wQ"]=label_legend
-            datalist2[k1]["label_lagend"]=label_def4
+            datalist2[k1]["label_legend_wQ"]=label_legend
+            datalist2[k1]["label_legend"]=label_def4
         for ip1 in range(len(parameters_list1[plot_params_in["dens_xaxis_parameter"]])):
             bool_eq1=True
             for ieq3,veq3 in enumerate(eq1):
                 v2=parameters_list1[eq_conditions_labels[ieq3]][ip1]
+                if bool_fixNatoms_linked and eq_conditions_labels[ieq3].find("fix_Natoms_")==0:
+                    continue
                 if not math.isclose(v2,veq3,rel_tol=1e-9):
                     bool_eq1=False
             if bool_eq1:
@@ -937,7 +951,7 @@ def plot_defect_densities(plot_params_in={}):
         for k1,d1 in defects_list_screened.items():
             l1,=ax1.plot(parameters_list_main,d1["values"],c=d1["line_color"],ls=d1["line_style"],lw=d1["line_width"])
             lines.append(l1)
-            legends.append(d1["label_lagend_wQ"])
+            legends.append(d1["label_legend_wQ"])
         if plot_params_in["Edef_zero_line"]:
             if np.abs(plot_params_in["Edef_y_lower_limit"])>1e-10:
                 ax1.axhline(0.0,color="k",ls=":",lw=1.0)
@@ -988,7 +1002,7 @@ def plot_defect_densities(plot_params_in={}):
         for k1,d1 in defects_list_screened.items():
             l1,=ax1.plot(parameters_list_main,d1["values"],c=d1["line_color"],ls=d1["line_style"],lw=d1["line_width"])
             lines.append(l1)
-            legends.append(d1["label_lagend_wQ"])
+            legends.append(d1["label_legend_wQ"])
         ax1.set_xlim([plot_params_in["dens_x_lower_limit"],plot_params_in["dens_x_upper_limit"]])
         if plot_params_in["dens_xaxis_log"]:
             ax1.set_xscale("log")
